package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Apr 4, 2022
License: GPL-3.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Errorf(format string, v ...interface{})
func Errorln(v ...interface{})
func Infof(format string, v ...interface{})
func Infoln(v ...interface{})
func InitLogger(debug, warn, error io.Writer)
func PrintHex(bytes []byte)
func Warnf(format string, v ...interface{})
func Warnln(v ...interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.